# log-utils [![NPM version](https://img.shields.io/npm/v/log-utils.svg?style=flat)](https://www.npmjs.com/package/log-utils) [![NPM downloads](https://img.shields.io/npm/dm/log-utils.svg?style=flat)](https://npmjs.org/package/log-utils) [![Build Status](https://img.shields.io/travis/jonschlinkert/log-utils.svg?style=flat)](https://travis-ci.org/jonschlinkert/log-utils)

Basic logging utils: colors, symbols and timestamp.

## Install

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save log-utils
```

All module dependencies are tiny and are lazily evaluated, this takes around ~1 millisecond to load.

## Usage

```js
var log = require('log-utils');
```

## API

### [.symbol.error](index.js#L44)

Error symbol.

**Example**

```js
console.log(log.symbol.error);
//=> ✖
```

### [.symbol.info](index.js#L59)

Info symbol.

**Example**

```js
console.log(log.symbol.info);
//=> ℹ
```

### [.symbol.success](index.js#L74)

Success symbol.

**Example**

```js
console.log(log.symbol.success);
//=> ✔
```

### [.symbol.warning](index.js#L89)

Warning symbol.

**Example**

```js
console.log(log.symbol.warning);
//=> ⚠
```

### [.error](index.js#L104)

Get a red error symbol.

**Example**

```js
console.log(log.error);
//=> ✖
```

### [.info](index.js#L119)

Get a cyan info symbol.

**Example**

```js
console.log(log.info);
//=> ℹ
```

### [.success](index.js#L134)

Get a green success symbol.

**Example**

```js
console.log(log.success);
//=> ✔
```

### [.warning](index.js#L149)

Get a yellow warning symbol.

**Example**

```js
console.log(log.warning);
//=> ⚠
```

### [.timestamp](index.js#L164)

Get a formatted timestamp.

**Example**

```js
console.log(log.timestamp);
//=> [15:27:46]
```

### [.ok](index.js#L179)

Log a white success message prefixed by a green check.

**Example**

```js
log.ok('Alright!');
//=> '✔ Alright!'
```

### [.heading](index.js#L193)

Make the given text bold and underlined.

**Example**

```js
console.log(log.heading('foo'));
// or
console.log(log.heading('foo', 'bar'));
```

### Colors

Available colors from [ansi-colors](https://github.com/doowb/ansi-colors):

* `.bgblack`
* `.bgblue`
* `.bgcyan`
* `.bggreen`
* `.bgmagenta`
* `.bgred`
* `.bgwhite`
* `.bgyellow`
* `.black`
* `.blue`
* `.bold`
* `.cyan`
* `.dim`
* `.gray`
* `.green`
* `.grey`
* `.hidden`
* `.inverse`
* `.italic`
* `.magenta`
* `.red`
* `.reset`
* `.strikethrough`
* `.underline`
* `.white`
* `.yellow`

## Changes

**v0.2.0 (2016-07-16)**

* `removed`: all spinner methods

**v0.1.5 (2016-07-16)**

* `added`: `.header` method
* `fixed`: `.ok` method, so that whitespace is respected

## Related projects

You might also be interested in these projects:

* [ansi-colors](https://www.npmjs.com/package/ansi-colors): Collection of ansi colors and styles. | [homepage](https://github.com/doowb/ansi-colors "Collection of ansi colors and styles.")
* [error-symbol](https://www.npmjs.com/package/error-symbol): Cross-platform error symbol. | [homepage](https://github.com/jonschlinkert/error-symbol "Cross-platform error symbol.")
* [info-symbol](https://www.npmjs.com/package/info-symbol): Cross-platform info symbol. | [homepage](https://github.com/jonschlinkert/info-symbol "Cross-platform info symbol.")
* [success-symbol](https://www.npmjs.com/package/success-symbol): Cross-platform success symbol. | [homepage](https://github.com/jonschlinkert/success-symbol "Cross-platform success symbol.")
* [warning-symbol](https://www.npmjs.com/package/warning-symbol): Cross-platform warning symbol. | [homepage](https://github.com/jonschlinkert/warning-symbol "Cross-platform warning symbol.")

## Contributing

This document was generated by [verb-readme-generator](https://github.com/verbose/verb-readme-generator) (a [verb](https://github.com/verbose/verb) generator), please don't edit directly. Any changes to the readme must be made in [.verb.md](.verb.md). See [Building Docs](#building-docs).

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

Or visit the [verb-readme-generator](https://github.com/verbose/verb-readme-generator) project to submit bug reports or pull requests for the readme layout template.

## Building docs

_(This document was generated by [verb-readme-generator](https://github.com/verbose/verb-readme-generator) (a [verb](https://github.com/verbose/verb) generator), please don't edit the readme directly. Any changes to the readme must be made in [.verb.md](.verb.md).)_

Generate readme and API documentation with [verb](https://github.com/verbose/verb):

```sh
$ npm install -g verb verb-readme-generator && verb
```

## Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

## Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

## License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/jonschlinkert/log-utils/blob/master/LICENSE).

***

_This file was generated by [verb](https://github.com/verbose/verb), v0.9.0, on July 11, 2016._